@@ -10,15 +10,13 @@ Optional scope to include 'email' and/or 'messages' separated by space:
 
 More information on scope can be found at https://angel.co/api/oauth/faq
 """
-import json
-from urllib import urlencode
-
 from social.backends.oauth import BaseOAuth2
 
 
 class AngelOAuth2(BaseOAuth2):
     name = 'angel'
     AUTHORIZATION_URL = 'https://angel.co/api/oauth/authorize/'
+    ACCESS_TOKEN_METHOD = 'POST'
     ACCESS_TOKEN_URL = 'https://angel.co/api/oauth/token/'
     REDIRECT_STATE = False
     STATE_PARAMETER = False
@@ -36,10 +34,6 @@ class AngelOAuth2(BaseOAuth2):
 
     def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
-        url = 'https://api.angel.co/1/me/?' + urlencode({
+        return self.get_json('https://api.angel.co/1/me/', params={
             'access_token': access_token
         })
-        try:
-            return json.load(self.urlopen(url))
-        except ValueError:
-            return None
