@@ -11,11 +11,7 @@ User screen name is used to generate username.
 By default account id is stored in extra_data field, check OAuthBackend
 class for details on how to extend it.
 """
-import json
-from urllib2 import HTTPError
-
 from social.backends.oauth import BaseOAuth2
-from social.exceptions import AuthCanceled
 
 
 class DailymotionOAuth2(BaseOAuth2):
@@ -26,24 +22,12 @@ class DailymotionOAuth2(BaseOAuth2):
     AUTHORIZATION_URL = 'https://api.dailymotion.com/oauth/authorize'
     REQUEST_TOKEN_URL = 'https://api.dailymotion.com/oauth/token'
     ACCESS_TOKEN_URL = 'https://api.dailymotion.com/oauth/token'
+    ACCESS_TOKEN_METHOD = 'POST'
 
     def get_user_details(self, response):
         return {'username': response.get('screenname')}
 
     def user_data(self, access_token, *args, **kwargs):
         """Return user data provided"""
-        # TODO: review
-        url = 'api.dailymotion.com' + access_token
-        try:
-            return json.loads(self.urlopen(url).read())
-        except (ValueError, HTTPError):
-            return None
-
-    def auth_complete(self, *args, **kwargs):
-        """Completes login process, must return user instance"""
-        if 'denied' in self.data:
-            raise AuthCanceled(self)
-        return super(DailymotionOAuth2, self).auth_complete(*args, **kwargs)
-
-    def oauth_request(self, token, url, extra_params=None):
-        return extra_params or {}
+        return self.get_json('https://api.dailymotion.com/me/',
+                             params={'access_token': access_token})
