@@ -1,6 +1,3 @@
-import json
-from urllib import urlencode
-
 from social.backends.oauth import BaseOAuth2
 
 
@@ -8,6 +5,7 @@ class FoursquareOAuth2(BaseOAuth2):
     name = 'foursquare'
     AUTHORIZATION_URL = 'https://foursquare.com/oauth2/authenticate'
     ACCESS_TOKEN_URL = 'https://foursquare.com/oauth2/access_token'
+    ACCESS_TOKEN_METHOD = 'POST'
 
     def get_user_id(self, details, response):
         return response['response']['user']['id']
@@ -24,10 +22,5 @@ class FoursquareOAuth2(BaseOAuth2):
 
     def user_data(self, access_token, *args, **kwargs):
         """Loads user data from service"""
-        url = 'https://api.foursquare.com/v2/users/self?' + urlencode({
-            'oauth_token': access_token
-        })
-        try:
-            return json.load(self.urlopen(url))
-        except ValueError:
-            return None
+        return self.get_json('https://api.foursquare.com/v2/users/self',
+                             params={'oauth_token': access_token})
