@@ -1,10 +1,6 @@
 """
 Mixcloud OAuth2 support
 """
-import json
-from urllib import urlencode
-from urllib2 import Request
-
 from social.backends.oauth import BaseOAuth2
 
 
@@ -13,6 +9,7 @@ class MixcloudOAuth2(BaseOAuth2):
     ID_KEY = 'username'
     AUTHORIZATION_URL = 'https://www.mixcloud.com/oauth/authorize'
     ACCESS_TOKEN_URL = 'https://www.mixcloud.com/oauth/access_token'
+    ACCESS_TOKEN_METHOD = 'POST'
 
     def get_user_details(self, response):
         return {'username': response['username'],
@@ -22,11 +19,6 @@ class MixcloudOAuth2(BaseOAuth2):
                 'last_name': None}
 
     def user_data(self, access_token, *args, **kwargs):
-        request = Request('https://api.mixcloud.com/me/?' + urlencode({
-            'access_token': access_token,
-            'alt': 'json'
-        }))
-        try:
-            return json.loads(self.urlopen(request).read())
-        except (ValueError, KeyError, IOError):
-            return None
+        return self.get_json('https://api.mixcloud.com/me/',
+                             params={'access_token': access_token,
+                                     'alt': 'json'})
