@@ -40,9 +40,9 @@ class RedditOAuth2(BaseOAuth2):
 
     def auth_headers(self):
         return {
-            'Authorization': 'Basic %s' % base64.urlsafe_b64encode(
-                ('%s:%s' % self.get_key_and_secret()).encode()
-            )
+            'Authorization': 'Basic {0}'.format(base64.urlsafe_b64encode(
+                ('{0}:{1}'.format(*self.get_key_and_secret()).encode())
+            ))
         }
 
     def refresh_token_params(self, token, redirect_uri=None, *args, **kwargs):
