@@ -3,6 +3,7 @@ import random
 import hashlib
 
 from social.utils import setting_name, to_setting_name
+from social.exceptions import NotAllowedToDisconnect
 from social.store import OpenIdStore
 
 
@@ -74,8 +75,20 @@ class BaseStrategy(object):
         return self.backend.continue_pipeline(*args, **kwargs)
 
     def disconnect(self, user, association_id=None):
-        self.storage.user.disconnect(name=self.backend.name, user=user,
-                                     association_id=association_id)
+        name = self.backend.name
+        user_storage = self.storage.user
+        revoke_token = self.setting('REVOKE_TOKENS_ON_DISCONNECT', False)
+        if user_storage.allowed_to_disconnect(user, name, association_id):
+            entries = user_storage.get_social_auth_for_user(user, name,
+                                                            association_id)
+            for entry in entries:
+                if revoke_token:
+                    backend = entry.get_backend(self)(self)
+                    backend.revoke_token(entry.extra_data['access_token'],
+                                         entry.uid)
+                user_storage.disconnect(entry)
+        else:
+            raise NotAllowedToDisconnect()
 
     def authenticate(self, *args, **kwargs):
         kwargs['strategy'] = self
@@ -143,7 +156,7 @@ class BaseStrategy(object):
             random.SystemRandom()
         except NotImplementedError:
             key = self.setting('SECRET_KEY', '')
-            seed = '%s%s%s' % (random.getstate(), time.time(), key)
+            seed = '{0}{1}{2}'.format(random.getstate(), time.time(), key)
             random.seed(hashlib.sha256(seed.encode()).digest())
         return ''.join([random.choice(chars) for i in range(length)])
 
